"""Slackware logo"""

from archey.colors import Colors

COLORS = [Colors.BLUE_NORMAL, Colors.BLUE_BRIGHT, Colors.CLEAR]

# pylint: disable=line-too-long
LOGO = [
    """{c[0]}                  {c[1]}:::::::{c[0]}                    """,
    """{c[0]}             {c[1]}:::::::::::::::::::{c[0]}             """,
    """{c[0]}          {c[1]}:::::::::::::::::::::::::{c[0]}          """,
    """{c[0]}        {c[1]}::::::::{c[2]}cllcccccllllllll{c[1]}::::::{c[0]}       """,
    """{c[0]}     {c[1]}:::::::::{c[2]}lc{c[0]}               {c[2]}dc{c[1]}:::::::{c[0]}     """,
    """{c[0]}    {c[1]}::::::::{c[2]}cl{c[0]}   {c[2]}clllccllll{c[0]}    {c[2]}oc{c[1]}:::::::::{c[0]}   """,
    """{c[0]}   {c[1]}:::::::::{c[2]}o{c[0]}   {c[2]}lc{c[1]}::::::::{c[2]}co{c[0]}   {c[2]}oc{c[1]}::::::::::{c[0]}  """,
    """{c[0]}  {c[1]}::::::::::{c[2]}o{c[0]}    {c[2]}cccclc{c[1]}:::::{c[2]}clcc{c[1]}::::::::::::{c[0]} """,
    """{c[0]}  {c[1]}:::::::::::{c[2]}lc{c[0]}        {c[2]}cclccclc{c[1]}:::::::::::::{c[0]} """,
    """{c[0]} {c[1]}::::::::::::::{c[2]}lcclcc{c[0]}          {c[2]}lc{c[1]}::::::::::::{c[0]}""",
    """{c[0]} {c[1]}::::::::::{c[2]}cclcc{c[1]}:::::{c[2]}lccclc{c[0]}     {c[2]}oc{c[1]}:::::::::::{c[0]}""",
    """{c[0]} {c[1]}::::::::::{c[2]}o{c[0]}    {c[2]}l{c[1]}::::::::::{c[2]}l{c[0]}    {c[2]}lc{c[1]}:::::::::::{c[0]}""",
    """{c[0]}  {c[1]}:::::{c[2]}c{c[0]} {c[0]}{c[1]}::{c[2]}o{c[0]}     {c[2]}clcllcccll{c[0]}     {c[2]}o{c[1]}:::::::::::{c[0]} """,
    """{c[0]}  {c[1]}:::::{c[2]}o{c[0]} {c[0]}{c[1]}:{c[2]}o{c[0]}                  {c[2]}clc{c[1]}:::::::::::{c[0]}  """,
    """{c[0]}   {c[1]}::::{c[2]}o{c[0]} {c[0]}{c[1]}:{c[2]}ccslclccclclccclclc{c[1]}:::::::::::::{c[0]}   """,
    """{c[0]}    {c[1]}:::{c[2]}o{c[0]}                             {c[1]}:::::{c[0]}   """,
    """{c[0]}     {c[1]}::{c[2]}lcccccccccccccccccccccccccccco{c[1]}::::{c[0]}    """,
    """{c[0]}       {c[1]}::::::::::::::::::::::::::::::::{c[0]}      """,
    """{c[0]}         {c[1]}::::::::::::::::::::::::::::{c[0]}        """,
    """{c[0]}            {c[1]}::::::::::::::::::::::{c[0]}           """,
    """{c[0]}                 {c[1]}::::::::::::{c[0]}                """,
]
